@@ -1,7 +1,5 @@
-import pandas as pd
 import torch
 from sentence_transformers import SentenceTransformer as SBERT
-
 from embetter.base import EmbetterBase
 
 
@@ -73,13 +71,8 @@ class SentenceEncoder(EmbetterBase):
         if not device:
             device = torch.device("cuda" if torch.cuda.is_available() else "cpu")
         self.name = name
-        self.device = device
-        self.tfm = SBERT(name, device=self.device)
+        self.tfm = SBERT(name, device=device)
 
     def transform(self, X, y=None):
         """Transforms the text into a numeric representation."""
-        # Convert pd.Series objects to encode compatable
-        if isinstance(X, pd.Series):
-            X = X.to_numpy()
-
         return self.tfm.encode(X)
