@@ -10,6 +10,11 @@ def test_readme():
     check_md_file(fpath="README.md")
 
 
+def test_finetune_docs():
+    """Docs need to be accurate"""
+    check_md_file(fpath="docs/finetuners.md", memory=True)
+
+
 objects = [
     ColumnGrabber,
     SentenceEncoder,
